@@ -28,4 +28,4 @@ class MappingProxyObject(PyObject[MappingProxyType, _KT, _VT_co]):
         cls, obj: MappingProxyType[_KT, _VT_co]
     ) -> MappingProxyObject[MappingProxyType, _KT, _VT_co]:
         """Create a MappingProxyObject from an object."""
-        return super(MappingProxyObject, cls).from_object(obj)  # type: ignore
+        return super().from_object(obj)  # type: ignore
