@@ -7,7 +7,7 @@ from typing import Sequence, TypeVar, overload
 from einspect.api import Py_ssize_t
 from einspect.compat import abc
 from einspect.errors import UnsafeIndexError
-from einspect.structs import PyTupleObject
+from einspect.structs import PyObject, PyTupleObject
 from einspect.utils import new_ref
 from einspect.views.unsafe import unsafe
 from einspect.views.view_base import VarView
@@ -34,15 +34,14 @@ class TupleView(VarView[tuple, None, _VT], abc.Sequence):
             try:
                 ptr = self._pyobject.GetItem(index)
                 py_struct = ptr.contents
-                py_obj = py_struct.into_object()
-                return py_obj.value
+                return py_struct.into_object()
             except IndexError as err:
                 raise IndexError(f"Index {index} out of range") from err
         elif isinstance(index, slice):
             start = index.start if index.start is not None else 0
             stop = index.stop if index.stop is not None else self.size
             ptr = self._pyobject.GetSlice(start, stop)
-            return ptr.contents.into_object().value
+            return ptr.contents.into_object()
         else:
             raise TypeError(f"Invalid index type: {type(index)}")
 
@@ -50,9 +49,8 @@ class TupleView(VarView[tuple, None, _VT], abc.Sequence):
         if isinstance(index, slice):
             raise ValueError("Cannot set slice of tuple")
         try:
-            ref = new_ref(value)
-            arr = self.item
-            arr[index] = ref
+            ref = PyObject.from_object(value).as_ref()
+            self.item[index] = ref
         except IndexError as err:
             if not self._unsafe:
                 raise UnsafeIndexError(
